@@ -9,12 +9,12 @@
 
 #include <QFile>
 #include <QTextStream>
+#include <QtAlgorithms>
 
-#include <qtemporaryfile.h>
+#include <QTemporaryFile>
 #include <kautosavefile.h>
 
 #include <QTest>
-#include <QTemporaryFile>
 
 QTEST_MAIN(KAutoSaveFileTest)
 
@@ -25,7 +25,7 @@ void KAutoSaveFileTest::initTestCase()
 
 void KAutoSaveFileTest::cleanupTestCase()
 {
-    for (const QString &fileToRemove : qAsConst(filesToRemove)) {
+    for (const QString &fileToRemove : std::as_const(filesToRemove)) {
         QFile::remove(fileToRemove);
     }
 }
@@ -38,7 +38,7 @@ void KAutoSaveFileTest::test_readWrite()
 
     QUrl normalFile = QUrl::fromLocalFile(QFileInfo(file).absoluteFilePath());
 
-    //Test basic functionality
+    // Test basic functionality
     KAutoSaveFile saveFile(normalFile);
 
     QVERIFY(!QFile::exists(saveFile.fileName()));
@@ -86,11 +86,7 @@ void KAutoSaveFileTest::test_fileNameMaxLength()
     // - exceeds NAME_MAX (255)
     // - is less than the maximum allowed path length, PATH_MAX (4096)
     //   see e.g. /usr/include/linux/limits.h
-    const QString path = QDir::tempPath() + QLatin1Char('/')
-                         + s + QLatin1Char('/')
-                         + s + QLatin1Char('/')
-                         + s + QLatin1Char('/')
-                         + s;
+    const QString path = QDir::tempPath() + QLatin1Char('/') + s + QLatin1Char('/') + s + QLatin1Char('/') + s + QLatin1Char('/') + s;
 
     QFile file(path + QLatin1Char('/') + QLatin1String("testFile.txt"));
 
@@ -111,10 +107,16 @@ void KAutoSaveFileTest::test_fileStaleFiles()
     KAutoSaveFile saveFile(normalFile);
     QVERIFY(saveFile.open(QIODevice::ReadWrite));
     saveFile.write("testdata");
+
     // Make sure the stale file is found
-    QVERIFY(saveFile.staleFiles(normalFile, QStringLiteral("qttest")).count() == 1);
+
+    const auto listOfStaleFiles = saveFile.staleFiles(normalFile, QStringLiteral("qttest"));
+    QVERIFY(listOfStaleFiles.count() == 1);
     saveFile.releaseLock();
+    qDeleteAll(listOfStaleFiles);
+
     // Make sure the stale file is deleted
+
     QVERIFY(saveFile.staleFiles(normalFile, QStringLiteral("qttest")).isEmpty());
 }
 
@@ -150,6 +152,5 @@ void KAutoSaveFileTest::test_locking()
 
     QVERIFY(saveFile2->open(QIODevice::ReadWrite));
 
-    delete saveFile2;
-
+    qDeleteAll(staleFiles);
 }
