@@ -1,34 +1,24 @@
-/* Private Header for class of KDirWatchPrivate
- *
- * this separate header file is needed for MOC processing
- * because KDirWatchPrivate has signals and slots
- *
- * This file is part of the KDE libraries
- * Copyright (C) 1998 Sven Radej <sven@lisa.exp.univie.ac.at>
- * Copyright (C) 2006 Dirk Mueller <mueller@kde.org>
- * Copyright (C) 2007 Flavio Castelli <flavio.castelli@gmail.com>
- * Copyright (C) 2008 Jarosław Staniek <staniek@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License version 2 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE libraries
+
+    SPDX-FileCopyrightText: 1998 Sven Radej <sven@lisa.exp.univie.ac.at>
+    SPDX-FileCopyrightText: 2006 Dirk Mueller <mueller@kde.org>
+    SPDX-FileCopyrightText: 2007 Flavio Castelli <flavio.castelli@gmail.com>
+    SPDX-FileCopyrightText: 2008 Jarosław Staniek <staniek@kde.org>
+    SPDX-FileCopyrightText: 2020 Harald Sitter <sitter@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-only
+
+    Private Header for class of KDirWatchPrivate
+    this separate header file is needed for MOC processing
+    because KDirWatchPrivate has signals and slots
+*/
 
 #ifndef KDIRWATCH_P_H
 #define KDIRWATCH_P_H
 
-#include <io/config-kdirwatch.h>
 #include "kdirwatch.h"
+#include <io/config-kdirwatch.h>
 
 #ifndef QT_NO_FILESYSTEMWATCHER
 #define HAVE_QFILESYSTEMWATCHER 1
@@ -37,20 +27,20 @@
 #endif
 
 #include <QList>
-#include <QSet>
 #include <QMap>
 #include <QObject>
+#include <QSet>
 #include <QString>
 #include <QTimer>
 class QSocketNotifier;
 
 #if HAVE_FAM
-#include <limits.h>
 #include <fam.h>
+#include <limits.h>
 #endif
 
-#include <sys/types.h> // time_t, ino_t
 #include <ctime>
+#include <sys/types.h> // time_t, ino_t
 
 #define invalid_ctime (static_cast<time_t>(-1))
 
@@ -65,26 +55,40 @@ class KDirWatchPrivate : public QObject
 {
     Q_OBJECT
 public:
-
-    enum entryStatus { Normal = 0, NonExistent };
-    enum entryMode { UnknownMode = 0, StatMode, INotifyMode, FAMMode, QFSWatchMode };
-    enum { NoChange = 0, Changed = 1, Created = 2, Deleted = 4 };
+    enum entryStatus {
+        Normal = 0,
+        NonExistent,
+    };
+    enum entryMode {
+        UnknownMode = 0,
+        StatMode,
+        INotifyMode,
+        FAMMode,
+        QFSWatchMode,
+    };
+    enum {
+        NoChange = 0,
+        Changed = 1,
+        Created = 2,
+        Deleted = 4,
+    };
 
     struct Client {
         Client(KDirWatch *inst, KDirWatch::WatchModes watchModes)
-            : instance(inst),
-            count(1),
-            watchingStopped(inst->isStopped()),
-            pending(NoChange),
-            m_watchModes(watchModes)
-        {}
+            : instance(inst)
+            , count(1)
+            , watchingStopped(inst->isStopped())
+            , pending(NoChange)
+            , m_watchModes(watchModes)
+        {
+        }
 
         // The compiler needs a copy ctor for Client when Entry is inserted into m_mapEntries
         // (even though the vector of clients is empty at that point, so no performance penalty there)
-        //Client(const Client &) = delete;
-        //Client &operator=(const Client &) = delete;
-        //Client(Client &&) = default;
-        //Client &operator=(Client &&) = default;
+        // Client(const Client &) = delete;
+        // Client &operator=(const Client &) = delete;
+        // Client(Client &&) = default;
+        // Client &operator=(Client &&) = default;
 
         KDirWatch *instance;
         int count;
@@ -127,7 +131,7 @@ public:
 
         Entry *findSubEntry(const QString &path) const
         {
-            for (Entry *sub_entry : qAsConst(m_entries)) {
+            for (Entry *sub_entry : std::as_const(m_entries)) {
                 if (sub_entry->path == path) {
                     return sub_entry;
                 }
@@ -141,6 +145,13 @@ public:
         QList<const Client *> clientsForFileOrDir(const QString &tpath, bool *isDir) const;
         QList<const Client *> inotifyClientsForFileOrDir(bool isDir) const;
 
+        std::vector<Client>::iterator findInstance(KDirWatch *other)
+        {
+            return std::find_if(m_clients.begin(), m_clients.end(), [other](const Client &client) {
+                return client.instance == other;
+            });
+        }
+
 #if HAVE_FAM
         FAMRequest fr;
         bool m_famReportedSeen;
@@ -160,12 +171,11 @@ public:
     typedef QMap<QString, Entry> EntryMap;
 
     KDirWatchPrivate();
-    ~KDirWatchPrivate();
+    ~KDirWatchPrivate() override;
 
     void resetList(KDirWatch *instance, bool skippedToo);
     void useFreq(Entry *e, int newFreq);
-    void addEntry(KDirWatch *instance, const QString &_path, Entry *sub_entry,
-                  bool isDir, KDirWatch::WatchModes watchModes = KDirWatch::WatchDirOnly);
+    void addEntry(KDirWatch *instance, const QString &_path, Entry *sub_entry, bool isDir, KDirWatch::WatchModes watchModes = KDirWatch::WatchDirOnly);
     void removeEntry(KDirWatch *instance, const QString &path, Entry *sub_entry);
     void removeEntry(KDirWatch *instance, Entry *e, Entry *sub_entry);
     bool stopEntryScan(KDirWatch *instance, Entry *e);
@@ -184,12 +194,15 @@ public:
 
     static bool isNoisyFile(const char *filename);
 
+    void ref();
+    void unref();
+
 public Q_SLOTS:
     void slotRescan();
     void famEventReceived(); // for FAM
     void inotifyEventReceived(); // for inotify
     void slotRemoveDelayed();
-    void fswEventReceived(const QString &path);  // for QFileSystemWatcher
+    void fswEventReceived(const QString &path); // for QFileSystemWatcher
 
 public:
     QTimer timer;
@@ -215,6 +228,7 @@ public:
 
     void checkFAMEvent(FAMEvent *fe);
     bool useFAM(Entry *e);
+    void disableFAM();
 #endif
 
 #if HAVE_SYS_INOTIFY_H
@@ -231,9 +245,12 @@ public:
 #endif
 
     bool _isStopped;
+
+private:
+    // Public objects that reference this thread-local private instance.
+    uint m_references;
 };
 
 QDebug operator<<(QDebug debug, const KDirWatchPrivate::Entry &entry);
 
 #endif // KDIRWATCH_P_H
-
