@@ -1,37 +1,30 @@
 /*
     This file is part of the KDE libraries
 
-    Copyright (c) 2002-2003 Oswald Buddenhagen <ossi@kde.org>
-    Copyright (c) 2003 Waldo Bastian <bastian@kde.org>
+    SPDX-FileCopyrightText: 2002-2003 Oswald Buddenhagen <ossi@kde.org>
+    SPDX-FileCopyrightText: 2003 Waldo Bastian <bastian@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kmacroexpander_p.h"
 
-#include <QStringList>
-#include <QStack>
 #include <QRegularExpression>
+#include <QStack>
+#include <QStringList>
 
 namespace KMacroExpander
 {
-
-enum Quoting { noquote, singlequote, doublequote, dollarquote,
-               paren, subst, group, math
-             };
+enum Quoting {
+    noquote,
+    singlequote,
+    doublequote,
+    dollarquote,
+    paren,
+    subst,
+    group,
+    math,
+};
 typedef struct {
     Quoting current;
     bool dquote;
@@ -49,10 +42,7 @@ using namespace KMacroExpander;
 
 inline static bool isSpecial(QChar cUnicode)
 {
-    static const uchar iqm[] = {
-        0xff, 0xff, 0xff, 0xff, 0xdf, 0x07, 0x00, 0xd8,
-        0x00, 0x00, 0x00, 0x38, 0x01, 0x00, 0x00, 0x78
-    }; // 0-32 \'"$`<>|;&(){}*?#!~[]
+    static const uchar iqm[] = {0xff, 0xff, 0xff, 0xff, 0xdf, 0x07, 0x00, 0xd8, 0x00, 0x00, 0x00, 0x38, 0x01, 0x00, 0x00, 0x78}; // 0-32 \'"$`<>|;&(){}*?#!~[]
 
     uint c = cUnicode.unicode();
     return (c < sizeof(iqm) * 8) && (iqm[c / 8] & (1 << (c & 7)));
@@ -63,11 +53,12 @@ static QString quoteArg(const QString &arg)
     if (!arg.length()) {
         return QStringLiteral("''");
     }
-    for (int i = 0; i < arg.length(); i++)
+    for (int i = 0; i < arg.length(); i++) {
         if (isSpecial(arg.unicode()[i])) {
             QChar q(QLatin1Char('\''));
             return q + QString(arg).replace(q, QLatin1String("'\\''")) + q;
         }
+    }
     return arg;
 }
 
@@ -88,7 +79,7 @@ bool KMacroExpanderBase::expandMacrosShellQuote(QString &str, int &pos)
     int len;
     int pos2;
     ushort ec = d->escapechar.unicode();
-    State state = { noquote, false };
+    State state = {noquote, false};
     QStack<State> sstack;
     QStack<Save> ostack;
     QStringList rst;
@@ -151,7 +142,7 @@ bool KMacroExpanderBase::expandMacrosShellQuote(QString &str, int &pos)
             if (cc == '(') {
                 sstack.push(state);
                 if (str.unicode()[pos + 1].unicode() == '(') {
-                    Save sav = { str, pos + 2 };
+                    Save sav = {str, pos + 2};
                     ostack.push(sav);
                     state.current = math;
                     pos += 2;
@@ -175,7 +166,7 @@ bool KMacroExpanderBase::expandMacrosShellQuote(QString &str, int &pos)
             }
             // always swallow the char -> prevent anomalies due to expansion
         } else if (cc == '`') {
-            str.replace(pos, 1, QStringLiteral("$( "));   // add space -> avoid creating $((
+            str.replace(pos, 1, QStringLiteral("$( ")); // add space -> avoid creating $((
             pos2 = pos += 3;
             for (;;) {
                 if (pos2 >= str.length()) {
@@ -188,8 +179,7 @@ bool KMacroExpanderBase::expandMacrosShellQuote(QString &str, int &pos)
                 }
                 if (cc == '\\') {
                     cc = str.unicode()[++pos2].unicode();
-                    if (cc == '$' || cc == '`' || cc == '\\' ||
-                            (cc == '"' && state.dquote)) {
+                    if (cc == '$' || cc == '`' || cc == '\\' || (cc == '"' && state.dquote)) {
                         str.remove(pos2 - 1, 1);
                         continue;
                     }
